==> python-docs-theme-lucit-1.0.0.tar.gz: python-docs-theme-lucit-1.0.0/README.md <==
[![GitHub Release](https://img.shields.io/github/release/LUCIT-Systems-and-Development/python-docs-theme-technopathy.svg?label=github)](https://github.com/LUCIT-Systems-and-Development/python-docs-theme-technopathy/releases)
[![PyPi Release](https://img.shields.io/pypi/v/python-docs-theme-technopathy?color=blue)](https://pypi.org/project/python-docs-theme-technopathy/)
[![Downloads](https://pepy.tech/badge/python-docs-theme-technopathy)](https://pepy.tech/project/python-docs-theme-technopathy)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/python-docs-theme-technopathy.svg) 
![PyPI - Status](https://img.shields.io/pypi/status/python-docs-theme-technopathy.svg) 
[![Github](https://img.shields.io/badge/source-github-orange)](https://github.com/LUCIT-Systems-and-Development/python-docs-theme-technopathy)

# Python Docs Sphinx Theme (LUCIT Edition)
Forked from https://github.com/python/python-docs-theme

## Installation

To use the theme, install it into your docs build environment via `pip`:
```
pip install python-docs-theme-technopathy
```
https://pypi.org/project/python-docs-theme-lucit

## Howto
https://www.technopathy.club/2019/11/03/use-python-sphinx-on-github-pages-with-html-and-an-indivdual-theme/

## Documentation
Settings for source/conf.py:
```
tml_theme = 'python_docs_theme_lucit'
html_context = {'github_repo_name': 'unicorn-binance-suite',
                'github_user_name': 'LUCIT-Systems-and-Development',
                'project_name': 'unicorn-binance-websocket-api'}
```
Demo conf.py: https://github.com/LUCIT-Systems-and-Development/python-simplemachinesforum/blob/master/sphinx/source/conf.py

### Elements are inherited by:
- https://github.com/sphinx-doc/sphinx/tree/master/sphinx/themes/default
- https://github.com/sphinx-doc/sphinx/tree/master/sphinx/themes/basic

## Commercial Support
[![LUCIT](https://www.lucit.tech/files/images/logos/LUCIT-LOGO-TRANS-PLAIN-NEW.png)](https://www.lucit.tech)

***Do you need a developer, operator or consultant?***

Contact [me](https://about.me/oliver-zehentleitner) for a non-binding initial consultation via my company 
[LUCIT](https://www.lucit.tech) from Vienna (Austria) or via [Telegram](https://t.me/LUCIT_OZ)/[WhatsApp](https://wa.me/436602456535).

==> python-docs-theme-lucit-1.0.2.tar.gz: python-docs-theme-lucit-1.0.2/README.md <==
[![GitHub Release](https://img.shields.io/github/release/LUCIT-Systems-and-Development/python-docs-theme-technopathy.svg?label=github)](https://github.com/LUCIT-Systems-and-Development/python-docs-theme-technopathy/releases)
[![PyPi Release](https://img.shields.io/pypi/v/python-docs-theme-technopathy?color=blue)](https://pypi.org/project/python-docs-theme-technopathy/)
[![Downloads](https://pepy.tech/badge/python-docs-theme-technopathy)](https://pepy.tech/project/python-docs-theme-technopathy)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/python-docs-theme-technopathy.svg) 
![PyPI - Status](https://img.shields.io/pypi/status/python-docs-theme-technopathy.svg) 
[![Github](https://img.shields.io/badge/source-github-orange)](https://github.com/LUCIT-Systems-and-Development/python-docs-theme-technopathy)

# Python Docs Sphinx Theme (LUCIT Edition)
Forked from https://github.com/python/python-docs-theme

## Installation

To use the theme, install it into your docs build environment via `pip`:
```
pip install python-docs-theme-technopathy
```
https://pypi.org/project/python-docs-theme-lucit

## Howto
https://www.technopathy.club/2019/11/03/use-python-sphinx-on-github-pages-with-html-and-an-indivdual-theme/

## Documentation
Settings for source/conf.py:
```
tml_theme = 'python_docs_theme_lucit'
html_context = {'github_repo_name': 'unicorn-binance-suite',
                'github_user_name': 'LUCIT-Systems-and-Development',
                'project_name': project}
```
Demo conf.py: https://github.com/LUCIT-Systems-and-Development/python-simplemachinesforum/blob/master/sphinx/source/conf.py

### Elements are inherited by:
- https://github.com/sphinx-doc/sphinx/tree/master/sphinx/themes/default
- https://github.com/sphinx-doc/sphinx/tree/master/sphinx/themes/basic

## Commercial Support
[![LUCIT](https://www.lucit.tech/files/images/logos/LUCIT-LOGO-TRANS-PLAIN-NEW.png)](https://www.lucit.tech)

***Do you need a developer, operator or consultant?***

Contact [me](https://about.me/oliver-zehentleitner) for a non-binding initial consultation via my company 
[LUCIT](https://www.lucit.tech) from Vienna (Austria) or via [Telegram](https://t.me/LUCIT_OZ)/[WhatsApp](https://wa.me/436602456535).
